@@ -1,3 +1,3 @@
 from .Marie import Marie
 from .MarieReader import MarieReader
-from .MarieGUI import *
\ No newline at end of file
+from .MarieGUI import MarieGUI, app
